product_title = [
                '갤럭시탭', '갤럭시노트', '갤럭시버즈','아이폰', '갤럭시', '프로', '울트라', '맥스', '아이패드', '에어팟', '플립', '폴드', '뮤패드', 'FE', 'FE+'
                '북', '맥북', 'S', 'Ultra', 'M1', 'M2', 'M3', 'M4', 'M5', 'Pro', 'ProMax', 'A', 'Tab', '맥', '미니', '북', '아이맥', '플러스','Z','+',
                'Galaxy', 'iPhone', 'iPad', 'MacBook', 'Zenbook', '그램', '에어', '스타일', '프로맥스', '미패드', 'Air', '탭', '노트', '버즈', 'AirPods',
                'Flip', 'Fold', 'MuPad', 'FE', 'FE+', 'Lite', '서피스', '고', '울트라북', '스튜디오', '베이직'
                  ]

product_type_dict = {
                      "pc" : "IT",
                      "mobilephone" : "IT",
                      "tablet" : "IT",
                      "laptop" : "IT",
}

type_code_name = {
    'refrigerator': '냉장고',
    'refrigeratorsingledoor': '싱글도어냉장고',
    'refrigeratortwodoor': '투도어냉장고',
    'washingmachine': '세탁기',
    'airconditioner': '에어컨',
    'ricecooker':     '밥솥',
    'vacuumcleaner':  '청소기',
    'dishwasher':     '식기세척기',
    'oven':           '오븐',
    'microwave':      '전자레인지',
    'coffeemachine':  '커피머신',
    'kimchirefrigerator': '김치냉장고',
    'dryer':          '건조기',
    'airpurifier':    '공기청정기',
    'razor':            '면도기',
    'waterpurifier':   '정수기',
    'monitor':          '모니터'
    # 필요한 만큼 더 추가
}

color_list = ["문스톤그레이", "스페이스 그레이", "코스믹 그레이", "내추럴", "카밍 차콜", "카밍그린", "오로라화이트", "잉크웰그레이",
              "스노우화이트", "새틴 화이트", "프라임 실버", "라벤더", "스페이스그레이", "루미다크실버", "미드나이트", "플래티넘실버",
              "스페이스 블랙", "그라파이트", "매트블랙", "사파이어", "스타라이트", "이클립스그레이", "새틴화이트", "보라퍼플",
              "글램화이트", "네이비블루", "메탈릭실버", "화이트실버", "카밍베이지", "페블 그레이", "블랙 메탈", "코타 화이트",
              "코타 퍼플", "크림라벤더", "크림 화이트", "크림화이트", "코타 차콜", "실버글라스", "블랙 크롬메탈", "샤인베이지",
              "에센셜화이트", "카밍그린", "크림레몬", "크림 그레이", "스페이스블랙", "실키크림", "샴페인골드", "실키오트밀", "펄 화이트",
              "크림그레이", "다크그레이", "모닝 블루", "그레이스화이트", "미스티 화이트", "에센셜 블루 그레이", "옥스포드그레이", "미스트 블루", "그래비티 그레이",
              "카밍클레이브라운", "사틴 차콜", "베르사유그레이", "매트블랙", "미스티라일락", "보타닉그린", "코튼플라워", "팬텀블랙", "시나모롤", "크림",
              "라이트블루", "다크레드", "라이트그린", "라임", "핑크골드", "딥퍼플", "화이트 티타늄", "블루 티타늄", "블랙 티타늄", "내추럴 티타늄",
              "실버", "베이지", "블랙", "화이트", "블루", "바이올렛", "옐로우", "그레이", "민트", "그린", "핑크", "퍼플", "차콜", "플래티넘", "옐로", "골드", "레드",
              "Black", "White", "Red", "Blue", "Green", "Yellow", "Pink", "Gray", "Silver", "Spacegray", "그레이그린"]

general_stopwords_list = [ '에듀몰', '해피투게딜', '자급제', '재고보유', '하이마트배송!', 'WQXGA +', '30만원대', '개별구매불가', '본체만구매', '자동취소', '1만','다운로드쿠폰',
                        '하이마트배송', '스태킹키트 포함', '스태킹키트 미포함', '한정판매', '한정수량', '온라인 전용', '1주이상소요/클리어런스', '스태킹/앵글',
                        '셀프관리형', '신모델', '즉시배송', '신상', '앵글설치포함,별도비용발생', '하이마트 설치', '최대36개월무', '사은품 증정', '제주마지막1대', '직렬설치',
                        '추가 다운로드 쿠폰', '국내정발', '빠른출발', '진열', '맞춤출수', '전시', '주연테크x하이메이드', '사내판매', '스태킹키트', '카드 추가',
                        '배송지연', '6개월주기 방문관리형', '익일배송', 'UP가전', '특가', '뭉치면싸다', '1만 다운로드 쿠폰', '1주차', '발송예정', '스태킹설치',
                        '사용안함', '스마트픽',  '미디어', '인버터', '정품OS', '단순배송', '2만원할인', '100원딜', '10대', '한정', '단독!', '단독', '추가 카드',
                        'AppleCare+', '1주이상소요', '**',  'DDR5', 'DDR4', 'DDR6', '시력보호', '최신형', '운영', '스태이션 포함!', '추가 쿠폰', '스태킹', '앵글',
                        '최종321만', '10대 한정판매',  '출고', '안드로이드', '배송시간 소요', '방문관리', 'i5.*?', 'i7.*?', 'win11', '20만원대', '링크!', '키트',
                        '사은품 증정', '2주이상 소요', '동시구매행사용', '1만원할인', '할인', '신학기특가', '키트포함', '키트 포함', 'CPU', 'GPU', 'RTX', 'GTX',
                        '각도조절형', '해피투게딜이벤트', '서랍형', '36개월케어십포함', '개별구매불가,본체만구매-자동취소', '전국무료설치', '8코어', '12코어', '16코어', '10코어',
                        '한정수량', '단종', '소진', '특가', '포토상품평이벤트', '어메이징','3월', '4월', '5월', '6월', '7월', '2주이상소요', '3주이상소요', 'NEW', '가벼운',
                        '8월', '9월', '10월', '11월', '12월', '1월', '2월', '행사', '1등급', '당질저감', '벽걸이조절형', '3년케어십', '초고온수', '기획전', '미포함', '포함',
                        '음성인식', '청정바람', '자가관리', '셀프형', '6개월', '방문주기', '시크릿 !', '최대', '10%', '신모델', '공동구매', '하이마트', '1만 다운로드 쿠폰',
                        '3개월', '창립기획', '단독모델', '스태킹설치포함', '자동먼지비움', '무빙키트' , '공기살균', '쇼핑몰', '배송!', '외장', '외장그래픽',
                        '전자동', '오프라인', '온라인', '전용', '개별구매불가 본체만구매-자동취소', '미세먼지극복', '병렬설치', '비밀', '앵글설치포함']